from apadata.text_processors.evaluators.elasticsearch_evaluator import (
    ElasticsearchEvaluator,
)


def test_elasticsearch_evaluator():
    evaluator = ElasticsearchEvaluator(
        all_keywords_list=["Consulting", "Management", "Software"]
    )
    keyword = "Consulting"
    assert evaluator.evaluate(keyword) == 1.0

    keyword = "Barbecue"
    assert evaluator.evaluate(keyword) == 0.0

    keyword = "Software management consulting"
    assert evaluator.evaluate(keyword) == 1.0

    keyword = "Nothing"
    assert evaluator.evaluate(keyword) == 0.0

    evaluator = ElasticsearchEvaluator()
    keyword = "Text"
    assert evaluator.evaluate(keyword) == 0.0
